Skip to contents

Create a blank line between other markdown block-level elements.

Usage

md_blank()

Value

A glue vector of length one containing two newline characters.

Details

Blank lines between block-level elements are ignored, except for the role they play in determining whether a list is tight or loose.

Blank lines at the beginning and end of the document are also ignored.

Examples

md_blank
#> function () 
#> {
#>     glue::glue("\n")
#> }
#> <bytecode: 0x556ce2c08ad8>
#> <environment: namespace:gluedown>