Take a character vector of valid markdown text and pass it to
markdown::markdownToHTML() to create a glue vector of HTML fragments.
Primarily used to test that md_*() functions create vectors that meet the
GFM spec and can be rendered as HTML.
Arguments
- x
A character vector of markdown text to be converted.
- frag
logical; Whether only a single HTML fragment should be returned.
TRUEby default.- disallow
logical; Should
md_disallow()be called on the converted output?
Details
GFM enables the tagfilter extension, where the following HTML tags will be
filtered when rendering HTML output...
See also
Other inline functions:
md_autolink(),
md_bold(),
md_code(),
md_disallow(),
md_escape(),
md_hardline(),
md_image(),
md_issue(),
md_italic(),
md_link(),
md_softline(),
md_strike(),
md_text()
Examples
md_convert(x = md_bold("test"))
#> <p><strong>test</strong></p>
#>