Skip to contents

Take a character vector and numeric vector and concatenate them into a glue vector of valid GitHub issue autolinks (username/repo#issue).

Usage

md_issue(repo, num)

Arguments

repo

A character vector in the format "user/rep".

num

The issue or pull number without hash symbol.

Value

A character vector which GitHub can automatically hyperlink.

Details

Within conversations on GitHub, references to issues and pull requests are automatically converted to shortened links.

Examples

md_issue("k5cents/gluedown", 1:5)
#> k5cents/gluedown#1
#> k5cents/gluedown#2
#> k5cents/gluedown#3
#> k5cents/gluedown#4
#> k5cents/gluedown#5