Create a glue vector of characters used to represent a thematic break. This
markdown leaf block is rendered as the <hr> HTML tag.
Usage
md_rule(char = c("*", "-", "_"), n = 3, space = FALSE)Details
A line consisting of 0-3 spaces of indentation, followed by a sequence of
three or more matching -, _, or * characters, each followed optionally
by any number of spaces or tabs, forms a thematic break.
See also
Other leaf block functions:
md_blank(),
md_chunk(),
md_fence(),
md_heading(),
md_indent(),
md_label(),
md_paragraph(),
md_reference(),
md_setext(),
md_table()