Take a character vector and wrap each element in tildes to create a glue
vector of strikethrough text. This inline is rendered as the <strike> HTML
tag.
Details
GFM enables the strikethrough extension, where an additional emphasis type is
available. Strikethrough text is any text wrapped in two tildes (~).
See also
Other inline functions:
md_autolink(),
md_bold(),
md_code(),
md_convert(),
md_disallow(),
md_escape(),
md_hardline(),
md_image(),
md_issue(),
md_italic(),
md_link(),
md_softline(),
md_text()
Other markdown extensions:
md_issue(),
md_table()