Create a blank line between other markdown block-level elements.
Details
Blank lines between block-level elements are ignored, except for the role they play in determining whether a list is tight or loose.
Blank lines at the beginning and end of the document are also ignored.
See also
Other leaf block functions:
md_chunk(),
md_fence(),
md_heading(),
md_indent(),
md_label(),
md_paragraph(),
md_reference(),
md_rule(),
md_setext(),
md_table()