Take a character vector and return a collapsed glue vector with each original
element separated by two spaces and a newline. This inline is rendered with a
<br /> HTML tag.
Usage
md_hardline(..., method = c("spaces", "backslash"))Details
A line break (not in a code span or HTML tag) that is preceded by two or more
spaces and does not occur at the end of a block is parsed as a hard line
break (rendered in HTML as a <br /> tag). CommonMark also supports a
backslash before a line ending as an alternative hard line break syntax.
See also
Other inline functions:
md_autolink(),
md_bold(),
md_code(),
md_convert(),
md_disallow(),
md_escape(),
md_image(),
md_issue(),
md_italic(),
md_link(),
md_softline(),
md_strike(),
md_text()