Take a character vector and numeric vector and concatenate them into a glue vector of valid GitHub issue autolinks (username/repo#issue).
Details
Within conversations on GitHub, references to issues and pull requests are automatically converted to shortened links.
See also
Other inline functions:
md_autolink(),
md_bold(),
md_code(),
md_convert(),
md_disallow(),
md_escape(),
md_hardline(),
md_image(),
md_italic(),
md_link(),
md_softline(),
md_strike(),
md_text()
Other markdown extensions:
md_strike(),
md_table()